local HeadCount = LibStub("AceAddon-3.0"):GetAddon("HeadCount2")
if not HeadCount then return end

local L = LibStub("AceLocale-3.0"):GetLocale("HeadCount2")
local BB = LibStub("LibBabble-Boss-3.0"):GetUnstrictLookupTable()

HeadCount.BOSS_ALIASES = {}
HeadCount.BOSS_BLACKLIST = {}
HeadCount.BOSS_WHITELIST = {}
-- Metadata
HeadCount.TITLE = "HeadCount2"
HeadCount.VERSION = GetAddOnMetadata(HeadCount.TITLE, "Version")
HeadCount.AUTHOR = GetAddOnMetadata(HeadCount.TITLE, "Author")
HeadCount.DEFAULT_LEVEL = 80
HeadCount.MESSAGE_PREFIX = "[HeadCount2]"
HeadCount.MAX_MESSAGE_LENGTH = 250
HeadCount.MAX_PLAYER_NAMES_PER_LINE = 15
-- Group info
HeadCount.NUMBER_OF_PARTY_PLAYERS = 5
HeadCount.NUMBER_OF_PARTY_GROUPS = 8
HeadCount.NUMBER_OF_NORMAL_PLAYERS = 10
HeadCount.NUMBER_OF_HEROIC_PLAYERS = 25
-- Loot and Boss constants
HeadCount.DEFAULT_LOOT_SOURCE = L["Trash mob"]
HeadCount.DEFAULT_LOOT_QUANTITY = 1
HeadCount.EVENT_OUTGOING_WHISPER_UPDATE_DELAY = 0.25

function HeadCount:InitializeConstants()
	-- Ice Crown
	self:AddToHash(self.BOSS_ALIASES,BB["Prince Valanar"],BB["Blood Council"])
	self:AddToHash(self.BOSS_ALIASES,BB["Prince Taldaram"],BB["Blood Council"])
	self:AddToHash(self.BOSS_ALIASES,BB["Prince Keleseth"],BB["Blood Council"])
	self:AddToHash(self.BOSS_ALIASES,BB["High Overlord Saurfang"],BB["Icecrown Gunship Battle"])
	self:AddToHash(self.BOSS_ALIASES,BB["Muradin Bronzebeard"],BB["Icecrown Gunship Battle"])
	-- BlackList
	self:AddToHash(self.BOSS_BLACKLIST,BB["Midnight"],true) -- Karazan
	self:AddToHash(self.BOSS_BLACKLIST,BB["Hellfire Channeler"],true) -- Mags Lair
	--- WhiteList
	self:AddToHash(self.BOSS_WHITELIST,BB["Lady Deathwhisper"],true)
end

function HeadCount:AddToHash(table, key,value)
	table[key] = value
end

-- group values
local MINIMUM_GROUP_NUMBER = 1
local MAXIMUM_GROUP_NUMBER = 8

local RAID_MEMBER_SORT = {
	["Name"] = "Name",
	["Start"] = "Start",
	["End"] = "End",
	["Total"] = "Total",
	["Waitlist"] = "Waitlist",
	["WaitlistNote"] = "WaitlistNote",
}
-- "You receive loot: %sx%d"
local MULTIPLE_LOOT_SELF_REGEX = (LOOT_ITEM_SELF_MULTIPLE):gsub("%%sx%%d", "(.+)x(%%d+)")
-- "You receive loot: %s"
local LOOT_SELF_REGEX = (LOOT_ITEM_SELF):gsub("%%s", "(.+)")
-- %s receives loot: %sx%d.
local MULTIPLE_LOOT_REGEX = (LOOT_ITEM_MULTIPLE):gsub("%%s receives loot: %%sx%%d", "(.+) receives loot: (.+)x(%%d+)")
-- %s receives loot: %s.
local LOOT_REGEX = (LOOT_ITEM):gsub("%%s", "(.+)")
-- Gets the multiple loot self regex
-- @return string Returns the multiple loot self regex
function HeadCount:getMULTIPLE_LOOT_SELF_REGEX()
	return MULTIPLE_LOOT_SELF_REGEX
end
-- Gets the loot self regex
-- @return string Returns the loot self regex
function HeadCount:getLOOT_SELF_REGEX()
	return LOOT_SELF_REGEX
end
-- Gets the multiple loot regex
-- @return string Returns the multiple loot regex
function HeadCount:getMULTIPLE_LOOT_REGEX()
	return MULTIPLE_LOOT_REGEX
end
-- Gets the loot regex
-- @return string Returns the loot regex
function HeadCount:getLOOT_REGEX()
	return LOOT_REGEX
end
-- Gets the raid member sort criteria.
-- @return table Returns the raid member sort criteria.
function HeadCount:getRAID_MEMBER_SORT()
	return RAID_MEMBER_SORT
end
-- Gets the minimum group number.
-- @return number Returns the minimum group number.
function HeadCount:getMINIMUM_GROUP_NUMBER()
	return MINIMUM_GROUP_NUMBER
end
-- Gets the maximum group number.
-- @return number Returns the maximum group number.
function HeadCount:getMAXIMUM_GROUP_NUMBER()
	return MAXIMUM_GROUP_NUMBER
end