local HeadCount = LibStub("AceAddon-3.0"):GetAddon("HeadCount2")

local Fields = {
	started = false,
	bosses = {},
	bossCount = 0,
	lastBoss = HeadCount.DEFAULT_LOOT_SOURCE
}

local BossEvent = HeadCount:NewClassFunctions()

function BossEvent:Init(args)
	if args then
		self.started = args["started"]
		self.bosses = args["bosses"]
		self.bossCount = args["bossCount"]
	end
	self.lastBoss = HeadCount.DEFAULT_LOOT_SOURCE
end
function BossEvent:AddBoss(bossID, name, zone, difficulty)
	assert(bossID,"Bossevent requires an ID")
	self.bosses[bossID] = {}
	self.bosses[bossID].name = name
	self.bosses[bossID].state = 1 -- Alive = 1, Dead = 2
	self.bosses[bossID].zone = zone
	self.bosses[bossID].difficulty = difficulty
	self.bossCount = self.bossCount + 1
	self.started = true
end

function BossEvent:Complete()
	if not self.started then return false end
	local db = 0
	for k,v in pairs(self.bosses) do
		if v.state == 2 then db = db + 1 end
	end
	if db == self.bossCount then return true end
	return false
end
function BossEvent:Stop(wipe)
	if not self.started then return end
	wipe(self.bosses)
	self.bossCount = 0
	if wipe then
		self.lastBoss = HeadCount.DEFAULT_LOOT_SOURCE
	end
	self.started = false
end

function BossEvent:GetName(guid)
	if self.bosses[guid] then return self.bosses[guid].name end
end

function BossEvent:GetGUID(name)
	local guid = nil
	for bossGUID, boss in pairs(self.bosses) do
		if boss.name == name then
			guid = bossGUID
		end
	end
	return guid
end

function BossEvent:IsPresent(guid)
	-- Check the Aliases
	return self.bosses[guid] and true or false
end

function BossEvent:GetZone(guid)
	if self.bosses[guid] then return self.bosses[guid].zone end
end

function BossEvent:AddKill(guid)
	if self.bosses[guid] then
		self.bosses[guid].state = 2
		self.lastBoss = self:GetName(guid)
	end
end

function BossEvent:IsDead(guid)
	return bosses[guid] and bosses[guid].state == 2 or false
end

function BossEvent:IsAlive(guid)
	return bosses[guid] and bosses[guid].state == 1 or false
end
-- Add the Class Definition to Registry
HeadCount:DefineClass("BossEvent",Fields,BossEvent)